#import "PAStringList.h"

/******************************************************************************
PAFilenameList

	The PAFilenameList (a subclass of PAStringList) is a convenient way to deal with lists of filenames. It contains methods for generating lists of filenames from given directories. There is also a specific method for searching the standard libraries (/NextLibrary, /LocalLibrary, ~/Libary). Files can be limited to particular extensions and can be returned with or without their full path and extension.
	
	Copyright 1992, Jeff Martin (jmartin@next.com) (415) 780-3833.
******************************************************************************/

@interface PAFilenameList : PAStringList
{
	char	*plLibs;				// Libary directories to be preloaded
	char	*plDirs;				// Directories to be preloaded
	char	*plExts;				// Extensions to be preloaded
	BOOL	plFromAppDir;			// Whether to preload from the AppWrapper
	BOOL	plFromBundleDir;		// Whether to preload from this bundle
	BOOL	plStripPath, plStripExt;// Whether to strip paths & ext from files
	BOOL	plIfAbsent, plSorted;	// Whether to 'add if absent' and sort
}

// Adding filenames
- addFilename:(const char *)filename stripPath:(BOOL)stripPath 
	stripExt:(BOOL)stripExt ifAbsent:(BOOL)ifAbsent noCopy:(BOOL)noCopy 
	sorted:(BOOL)sorted at:(int)at;

// Adding arrays of filenames or another PAFilenameList
- addFilenames:(const char *const*)filenames stripPath:(BOOL)stripPath 
	stripExt:(BOOL)stripExt ifAbsent:(BOOL)ifAbsent noCopy:(BOOL)noCopy 
	sorted:(BOOL)sorted at:(int)at;
- addPAFilenameList:filenameListObject stripPath:(BOOL)stripPath 
	stripExt:(BOOL)stripExt ifAbsent:(BOOL)ifAbsent noCopy:(BOOL)noCopy 
	sorted:(BOOL)sorted at:(int)at;

// Adding individual filenames from delimited (tab or otherwise) string
- addDelimitedFilenames:(const char *)string delimiters:(const char *)dels 
	stripPath:(BOOL)stripPath stripExt:(BOOL)stripExt ifAbsent:(BOOL)ifAbsent 
	sorted:(BOOL)sorted at:(int)at;

// Adding filenames from directories
- addFilenamesFromDirectories:(const char *)dirs withExts:(const char *)exts 
	stripPath:(BOOL)stripPath stripExt:(BOOL)stripExt ifAbsent:(BOOL)ifAbsent 
	sorted:(BOOL)sorted at:(int)at;
- addFilenamesFromStandardLibrariesDirectories:(const char *)dirs
	withExts:(const char *)exts stripPath:(BOOL)stripPath 
	stripExt:(BOOL)stripExt ifAbsent:(BOOL)ifAbsent sorted:(BOOL)sorted 
	at:(int)at;

// Sorting Strings
- sortFilenamesIgnoringPath:sender;
int filenameCmp(const void *s1, const void *s2);

// Preloading strings
- (const char *)preLoadLibraries;
- setPreLoadLibraries:(const char *)libraries;

- (const char *)preLoadDirectories;
- setPreLoadDirectories:(const char *)directories;

- (const char *)preLoadExtensions;
- setPreLoadExtensions:(const char *)extensions;

- (BOOL)preLoadFromAppDir;
- setPreLoadFromAppDir:(BOOL)flag;

- (BOOL)preLoadFromBundleDir;
- setPreLoadFromBundleDir:(BOOL)flag;

- (BOOL)preLoadStripPath;
- setPreLoadStripPath:(BOOL)flag;

- (BOOL)preLoadStripExt;
- setPreLoadStripExt:(BOOL)flag;

- (BOOL)preLoadIfAbsent;
- setPreLoadIfAbsent:(BOOL)flag;

- (BOOL)preLoadSorted;
- setPreLoadSorted:(BOOL)flag;

// Archiving
- write:(NXTypedStream *)stream;
- read:(NXTypedStream *)stream;

@end

char *PAExpandFilename(char *fn);
